@@ -1,14 +1,15 @@
 /*
  * gbsplay is a Gameboy sound player
  *
- * 2003-2005,2008 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
- *                       Christian Garbs <mitch@cgarbs.de>
+ * 2003-2021 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
+ *                  Christian Garbs <mitch@cgarbs.de>
+ *
  * Licensed under GNU GPL v1 or, at your option, any later version.
  */
 
-#include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include <fcntl.h>
 #include <ctype.h>
 #include <string.h>
@@ -19,11 +20,11 @@
 #include "plugout.h"
 
 static long cfg_line, cfg_char;
-static /*@null@*/ FILE *cfg_file;
+static FILE *cfg_file;
 
 static long nextchar_state;
 
-static regparm char nextchar(void)
+static char nextchar(void)
 {
 	long c;
 
@@ -60,7 +61,7 @@ static long nextstate;
 static long c;
 static const char *filename;
 
-static regparm void err_expect(char *s)
+static void err_expect(const char* const s)
 {
 	fprintf(stderr, _("'%s' expected at %s line %ld char %ld.\n"),
 	        s, filename, cfg_line, cfg_char);
@@ -69,7 +70,7 @@ static regparm void err_expect(char *s)
 	nextstate = 1;
 }
 
-regparm void cfg_endian(void *ptr)
+void cfg_endian(void* const ptr)
 {
 	enum plugout_endian *endian = ptr;
 
@@ -90,7 +91,7 @@ regparm void cfg_endian(void *ptr)
 	nextstate = 1;
 }
 
-regparm void cfg_string(void *ptr)
+void cfg_string(void * const ptr)
 {
 	char s[200];
 	unsigned long n = 0;
@@ -112,7 +113,7 @@ regparm void cfg_string(void *ptr)
 	nextstate = 1;
 }
 
-regparm void cfg_long(void *ptr)
+void cfg_long(void* const ptr)
 {
 	char num[20];
 	unsigned long n = 0;
@@ -134,7 +135,29 @@ regparm void cfg_long(void *ptr)
 	nextstate = 1;
 }
 
-regparm void cfg_parse(const char *fname, const struct cfg_option *options)
+void cfg_int(void* const ptr)
+{
+	char num[10];
+	unsigned long n = 0;
+
+	if (!isdigit(c)) {
+		err_expect("[0-9]");
+		return;
+	}
+	do {
+		num[n++] = c;
+		c = nextchar();
+	} while (isdigit(c) &&
+	         n < (sizeof(num)-1));
+	num[n] = 0;
+
+	*((int*)ptr) = atoi(num);
+
+	state = 0;
+	nextstate = 1;
+}
+
+void cfg_parse(const char* const fname, const struct cfg_option* const options)
 {
 	char option[200] = "";
 
@@ -203,7 +226,7 @@ regparm void cfg_parse(const char *fname, const struct cfg_option *options)
 	(void)fclose(cfg_file);
 }
 
-regparm char* get_userconfig(const char* cfgfile)
+char* get_userconfig(const char* const cfgfile)
 {
 	char *homedir, *usercfg;
 	long length;
