@@ -1,7 +1,9 @@
 /*
  * gbsplay is a Gameboy sound player
  *
- * 2003-2005 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
+ * 2003-2021 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
+ *                  Christian Garbs <mitch@cgarbs.de>
+ *
  * Licensed under GNU GPL v1 or, at your option, any later version.
  */
 
@@ -9,6 +11,7 @@
 #define _GBCPU_H_
 
 #include <inttypes.h>
+
 #include "common.h"
 
 #define ZF	0x80
@@ -55,7 +58,7 @@ static inline void foo(void)
 
 #endif
 
-#if BYTE_ORDER == LITTLE_ENDIAN
+#if GBS_BYTE_ORDER == GBS_ORDER_LITTLE_ENDIAN
 
 #define REGS16_R(r, i) (r.rw[i])
 #define REGS16_W(r, i, x) (r.rw[i]) = x
@@ -105,19 +108,44 @@ typedef union {
 
 #endif
 
-typedef regparm void (*gbcpu_put_fn)(uint32_t addr, uint8_t val);
-typedef regparm uint32_t (*gbcpu_get_fn)(uint32_t addr);
+typedef void (*gbcpu_put_fn)(void *priv, uint32_t addr, uint8_t val);
+typedef uint32_t (*gbcpu_get_fn)(void *priv, uint32_t addr);
 
-extern gbcpu_regs_u gbcpu_regs;
-extern long gbcpu_halt_at_pc;
-extern long gbcpu_halted;
-extern long gbcpu_if;
+struct get_entry {
+	void *priv;
+	gbcpu_get_fn get;
+};
 
-regparm void gbcpu_addmem(uint32_t start, uint32_t end, gbcpu_put_fn putfn, gbcpu_get_fn getfn);
-regparm void gbcpu_init(void);
-regparm long gbcpu_step(void);
-regparm void gbcpu_intr(long vec);
-regparm uint8_t gbcpu_mem_get(uint16_t addr);
-regparm void gbcpu_mem_put(uint16_t addr, uint8_t val);
+struct put_entry {
+	void *priv;
+	gbcpu_put_fn put;
+};
+
+#define GBCPU_LOOKUP_SIZE 256
+
+struct gbcpu {
+	gbcpu_regs_u regs;
+	long halt_at_pc;
+	long halted;
+	long ime;
+
+	long stopped;
+	cycles_t cycles;
+
+#if DEBUG == 1
+	gbcpu_regs_u oldregs;
+#endif
+	
+	struct get_entry getlookup[GBCPU_LOOKUP_SIZE];
+	struct put_entry putlookup[GBCPU_LOOKUP_SIZE];
+};
+
+void gbcpu_add_mem(struct gbcpu* const gbcpu, uint32_t start, uint32_t end, gbcpu_put_fn putfn, gbcpu_get_fn getfn, void *priv);
+void gbcpu_init(struct gbcpu* const gbcpu);
+void gbcpu_init_struct(struct gbcpu* const gbcpu);
+long gbcpu_step(struct gbcpu* const gbcpu);
+void gbcpu_intr(struct gbcpu* const gbcpu, long vec);
+uint8_t gbcpu_mem_get(struct gbcpu* const gbcpu, uint16_t addr);
+void gbcpu_mem_put(struct gbcpu* const gbcpu, uint16_t addr, uint8_t val);
 
 #endif
