@@ -1,11 +1,13 @@
 /*
  * gbsplay is a Gameboy sound player
  *
- * 2003-2005 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
+ * 2003-2021 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
  *                  Christian Garbs <mitch@cgarbs.de>
+ *
  * Licensed under GNU GPL v1 or, at your option, any later version.
  */
 
+#include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -13,7 +15,8 @@
 #include "common.h"
 #include "gbhw.h"
 #include "gbcpu.h"
-#include "gbs.h"
+#include "libgbs.h"
+#include "gbs_internal.h"
 
 /* global variables */
 char *myname;
@@ -71,7 +74,7 @@ int main(int argc, char **argv)
         }
 
 	if ((gbs = gbs_open(argv[0])) == NULL) exit(EXIT_FAILURE);
-	gbs_printinfo(gbs, 1);
+	gbs_internal_api.print_info(gbs, 1);
 	gbs_close(gbs);
 
 	return 0;
