@@ -1,7 +1,8 @@
 /*
  * gbsplay is a Gameboy sound player
  *
- * 2011 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
+ * 2011-2020 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
+ *
  * Licensed under GNU GPL v1 or, at your option, any later version.
  */
 
@@ -20,6 +21,7 @@
 #define ASSERT_ARRAY_EQUAL(fmt, a, b) do { \
 	int pass = 1; \
 	int i; \
+	char *cmp; \
 	for (i=0; i<sizeof(a)/sizeof(*(a)); i++) { \
 		if ((a)[i] == (b)[i]) \
 			continue; \
@@ -30,9 +32,11 @@
 		return; \
 	fprintf(stderr, "FAIL\nTest failed at %s:%d\n", __FILE__, __LINE__); \
 	for (i=0; i<sizeof(a)/sizeof(*(a)); i++) { \
-		/* if ((a)[i] == (b)[i]) \
-			continue; */ \
-		fprintf(stderr, "%d: "fmt" != "fmt"\n", i, (a)[i], (b)[i]); \
+		if ((a)[i] == (b)[i]) \
+			cmp = "=="; \
+		else \
+			cmp = "!="; \
+		fprintf(stderr, "%4d: "fmt" %s "fmt"\n", i, (a)[i], cmp, (b)[i]); \
 	} \
 	exit(1); \
 } while(0)
@@ -53,7 +57,7 @@
 typedef void (*test_fn)(void);
 struct test_entry {
 	test_fn func;
-	const char* name;
+	const char* const name;
 };
 
 #define TEST(func) test_entries struct test_entry test_ ## func = { func, #func }
